@@ -381,7 +381,7 @@ C     INVERSE OF AR(B) COMPUTATION
       IG=0
 cc	CALL INVERS(B,IQ,A,0,CC,IB,IG)
 cx      CALL INVERS(B,JQ,A,0,CC,IB,IG,IFG,LU)
-      CALL INVERS(B,JQ,A,0,CC,IB,IST,IG,IFG,LU)
+      CALL INVERS(B,JQ,A,0,CC,IB,ICST,IG,IFG,LU)
 cc	WRITE(6,4289) IB
 cx      IF (IFG.NE.0) WRITE(LU,4289) IB
 cc 4290 IF(IP.LE.0) GO TO 4291
