@@ -162,7 +162,8 @@ C     MM: THE TOTAL NUMBER OF INPUTS (LESS THAN 10)
 C     MJ: ABSOLUTE DIMENSION OF X IN THE MAIN ROUTINE
       IMPLICIT COMPLEX*16(X)
       DIMENSION X(MJ,MJ)
-      DIMENSION IDS(10)
+cx      DIMENSION IDS(10)
+      DIMENSION IDS(MM)
       XDET=1.0D-00
       MP1=MM+1
       DO 10 L=1,MM
